Analysis 
======================

FermiAnalysis
----------------------

.. autoclass:: vtspy.analysis.FermiAnalysis
   :show-inheritance:
   :members:
   :inherited-members:
   

VeritasAnalysis
----------------------

.. autoclass:: vtspy.analysis.VeritasAnalysis
   :show-inheritance:
   :members:
   :inherited-members:
   

JointAnalysis
----------------------

.. autoclass:: vtspy.analysis.JointAnalysis
   :show-inheritance:
   :members:
   :inherited-members:
   